@@ -1,40 +1,7 @@
 package Module::Setup::Flavor::Default;
 use strict;
 use warnings;
-use base 'Module::Setup::Flavor';
-
-
-sub setup_config {
-    my($class, $context, $config) = @_;
-
-    my %vcs = (
-        SVN => 'VC::SVN',
-        SVK => 'VC::SVK',
-        Git => 'VC::Git',
-    );
-
-    for my $name (qw/ SVN SVK Git /) {
-        my $pkg = $vcs{$name};
-        next unless $context->dialog("Do you use $name? [yN]", 'n') =~ /[Yy]/;
-        $context->log("You chose version control system: $name");
-
-        next if grep {
-            ( ref($_) eq 'HASH' && $_->{module} eq $pkg) || $_ eq $pkg
-        } @{ $config->{plugins} };
-
-        push @{ $config->{plugins} }, $pkg;
-    }
-
-    if(grep {
-        ( ref($_) eq 'HASH' && $_->{module} eq 'VC::SVK') || $_ eq 'VC::SVK'
-    } @{ $config->{plugins} }) {
-        my @plugins = grep {
-            !(( ref($_) eq 'HASH' && $_->{module} eq 'VC::SVN') || $_ eq 'VC::SVN')
-        } @{ $config->{plugins} };
-        $config->{plugins} = \@plugins;
-    }
-
-}
+use base 'Module::Setup::Flavor::SelectVC';
 
 1;
 
@@ -55,15 +22,15 @@ file: Makefile.PL
 template: |
   use inc::Module::Install;
   name '[% dist %]';
-  all_from 'lib/[% module_path %].pm';
+  all_from 'lib/[% module_unix_path %].pm';
 
   # requires '';
 
   tests 't/*.t';
   author_tests 'xt';
 
-  build_requires 'Test::More';
-  use_test_base;
+  test_requires 'Test::More';
+  auto_set_repository;
   auto_include;
   WriteAll;
 ---
@@ -120,7 +87,6 @@ template: |
 file: lib/____var-module_path-var____.pm
 template: |
   package [% module %];
-
   use strict;
   use warnings;
   our $VERSION = '0.01';
@@ -174,6 +140,8 @@ template: |
   ^[^/]+\.yaml$
   ^[^/]+\.pl$
   ^\.shipit$
+  ^\.git/
+  \.sw[po]$
 ---
 file: README
 template: |
@@ -209,7 +177,6 @@ file: .shipit
 chmod: 0644
 template: |
   steps = FindVersion, ChangeVersion, CheckChangeLog, DistTest, Commit, Tag, MakeDist, UploadCPAN
-  svk.tagpattern = release-%v
 ---
 config:
   plugins:
