@@ -3,6 +3,8 @@ use strict;
 use warnings;
 use base 'Module::Setup::Path::Base';
 
+use YAML ();
+
 use Module::Setup::Path::Config;
 use Module::Setup::Path::Plugins;
 use Module::Setup::Path::Template;
@@ -25,4 +27,14 @@ sub plugins  { shift->{plugins} }
 sub template { shift->{template} }
 sub additional { shift->{additional} }
 
+sub create_flavor {
+    my($self, $config) = @_;
+
+    $self->path->mkpath;
+    $self->plugins->path->mkpath;
+    $self->template->path->mkpath;
+    $self->additional->path->mkpath;
+    YAML::DumpFile($self->config->path, $config);
+}
+
 1;
